@@ -85,6 +85,7 @@ def _get_current_release():
 
 source_table = {
   'git': scm.Git,
+  'mercurial': scm.Mercurial,
 }
 cset('source', (lambda: source_table.get(fetch('scm'))()))
 cset('revision', (lambda: fetch('source').head()))
@@ -93,6 +94,7 @@ cset('revision', (lambda: fetch('source').head()))
 cset('deploy_via', 'local_cache')
 strategy_table = {
   'local_cache': strategy.LocalCacheStrategy,
+  'checkout': strategy.CheckoutStrategy,
 }
 cset('strategy', (lambda: strategy_table.get(fetch('deploy_via'))()))
 
